@@ -1,9 +1,11 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # coding=utf-8
 
 import argparse
 import json
 
+import jsonschema
+
 import awp.packager
 import awp.validator
 
@@ -13,8 +15,8 @@ def parse_cli_args():
 
     parser = argparse.ArgumentParser()
     parser.add_argument(
-        '--validate', action='store_true',
-        help='validates the utility configuration file for this project')
+        '--force', '-f', action='store_true',
+        help='forces the copying of all files and directories')
     parser.add_argument(
         '--export', '-e', nargs='?', const='', default=None,
         help='exports the installed workflow to the local project directory')
@@ -35,13 +37,15 @@ def main():
     cli_args = parse_cli_args()
     config = get_utility_config()
 
-    if cli_args.validate:
+    try:
         awp.validator.validate_config(config)
-    else:
         awp.packager.package_workflow(
             config,
             version=cli_args.version,
-            export_file=cli_args.export)
+            export_file=cli_args.export,
+            force=cli_args.force)
+    except jsonschema.exceptions.ValidationError as error:
+        print('awp (from packager.json): {}'.format(error.message))
 
 
 if __name__ == '__main__':
